# MouseJiggler
A Python CLI (Command Line Interface) that jiggles the mouse to simulate activity. This tool can be used to make it appear as if you are actively using your computer, even when you are not.
